summaryrefslogtreecommitdiff
path: root/cmake
diff options
context:
space:
mode:
authorAzat Khuzhin <azat@libevent.org>2020-10-04 22:56:30 +0300
committerAzat Khuzhin <azat@libevent.org>2020-10-04 22:59:12 +0300
commit19d0bdfe0c89381ce0bc28c61a9f960a4f568009 (patch)
tree3030b6d01192804c7e7933ad11a523820b296596 /cmake
parent21b91692dadd9940a95153a27d7c88a82ea3df62 (diff)
downloadlibevent-19d0bdfe0c89381ce0bc28c61a9f960a4f568009.tar.gz
Change prefix for man pages from "le_" to "libevent_"
As pointed by @kloczek: "With only two characters it would be harder to guess under what kind of name are libevent lvl 3 man pages. Longer name with bash/fix/zsh tab competition should not be a problem :)" Refs: #1099
Diffstat (limited to 'cmake')
-rw-r--r--cmake/RenameDoxygen.cmake8
-rw-r--r--cmake/UseDoxygen.cmake2
2 files changed, 5 insertions, 5 deletions
diff --git a/cmake/UseDoxygen.cmake b/cmake/UseDoxygen.cmake
index 83a98011..c7e4b175 100644
--- a/cmake/UseDoxygen.cmake
+++ b/cmake/UseDoxygen.cmake
@@ -97,7 +97,7 @@ macro(UseDoxygen)
if ("${DOXYGEN_GENERATE_MAN}" STREQUAL "YES")
set(MAN_PAGES_DIR ${PROJECT_BINARY_DIR}/${DOXYGEN_OUTPUT_DIRECTORY}/man/man3)
- # Add prefix "le_" for manual pages
+ # Add prefix "libevent_" for manual pages
add_custom_target(doxygen-rename-man-pages ALL
COMMAND ${CMAKE_COMMAND} -P ${CMAKE_CURRENT_SOURCE_DIR}/cmake/RenameDoxygen.cmake
DEPENDS doxygen
diff --git a/cmake/RenameDoxygen.cmake b/cmake/RenameDoxygen.cmake
index 43a75af4..3260c3d2 100644
--- a/cmake/RenameDoxygen.cmake
+++ b/cmake/RenameDoxygen.cmake
@@ -1,9 +1,9 @@
# Add prefix "le_" for manual pages
message(STATUS "Rename man pages in ${CMAKE_BINARY_DIR}")
# Remove old pages to avoid stalled copies
-file(GLOB LIBEVENT_MAN_PAGES RELATIVE ${CMAKE_BINARY_DIR} le_*)
+file(GLOB LIBEVENT_MAN_PAGES RELATIVE ${CMAKE_BINARY_DIR} libevent_*)
list(LENGTH LIBEVENT_MAN_PAGES LEN)
if (${LEN} GREATER 0)
file(REMOVE ${LIBEVENT_MAN_PAGES})
@@ -11,7 +11,7 @@ endif()
# Create new
file(GLOB LIBEVENT_MAN_PAGES RELATIVE ${CMAKE_BINARY_DIR} *)
-list(FILTER LIBEVENT_MAN_PAGES EXCLUDE REGEX ^le_.*$)
+list(FILTER LIBEVENT_MAN_PAGES EXCLUDE REGEX ^libevent_.*$)
foreach(MAN_PAGE ${LIBEVENT_MAN_PAGES})
- file(RENAME ${CMAKE_BINARY_DIR}/${MAN_PAGE} ${CMAKE_BINARY_DIR}/le_${MAN_PAGE})
+ file(RENAME ${CMAKE_BINARY_DIR}/${MAN_PAGE} ${CMAKE_BINARY_DIR}/libevent_${MAN_PAGE})
endforeach()
@@ -1,9 +1,9 @@
-# Add prefix "le_" for manual pages
+# Add prefix "libevent_" for manual pages
message(STATUS "Rename man pages in ${CMAKE_BINARY_DIR}")
# Remove old pages to avoid stalled copies